@@ -18,10 +18,33 @@ export class PatientProgramRegistration extends Model {
   declare deactivatedClinicianId?: string;
   declare deactivatedDate?: string;
 
-  static initModel({ primaryKey, ...options }: InitOptions) {
+  static initModel(options: InitOptions) {
     super.init(
       {
-        id: primaryKey,
+        id: {
+          // patient_program_registration records use a generated primary key that enforces
+          // one per patient and program registry, even across a distributed sync system
+          type: `TEXT GENERATED ALWAYS AS (REPLACE("patient_id", ';', ':') || ';' || REPLACE("program_registry_id", ';', ':')) STORED`,
+          set() {
+            // any sets of the convenience generated "id" field can be ignored
+          },
+        },
+        patientId: {
+          type: DataTypes.STRING,
+          primaryKey: true,
+          references: {
+            model: 'patients',
+            key: 'id',
+          },
+        },
+        programRegistryId: {
+          type: DataTypes.STRING,
+          primaryKey: true,
+          references: {
+            model: 'program_registries',
+            key: 'id',
+          },
+        },
         date: dateTimeType('date', {
           allowNull: false,
           defaultValue: getCurrentDateTimeString,
@@ -126,7 +149,7 @@ export class PatientProgramRegistration extends Model {
     return null;
   }
 
-  static buildSyncLookupQueryDetails() {
+  static async buildSyncLookupQueryDetails() {
     return null; // syncs everywhere
   }
 }
