@@ -1,6 +1,7 @@
 export * from './User';
 export * from './UserRecentlyViewedPatient';
 export * from './UserPreference';
+export * from './UserLoginAttempt';
 export * from './LocalSystemFact';
 export * from './PortalUser';
 export * from './Device';
@@ -59,6 +60,7 @@ export * from './LabTestPanelLabTestTypes';
 export * from './ImagingRequest';
 export * from './ImagingRequestArea';
 export * from './ImagingAreaExternalCode';
+export * from './ImagingTypeExternalCode';
 export * from './ImagingResult';
 
 export * from './Program';
@@ -99,6 +101,7 @@ export * from './UserLocalisationCache';
 export * from './Asset';
 export * from './Appointment';
 export * from './AppointmentSchedule';
+export * from './AppointmentProcedureType';
 export * from './DocumentMetadata';
 export * from './Template';
 
@@ -109,22 +112,16 @@ export * from './Permission';
 export * from './Role';
 
 export * from './Invoice';
-export * from './InvoiceProduct';
-export * from './InvoiceDiscount';
-export * from './InvoiceInsurer';
-export * from './InvoiceItem';
-export * from './InvoiceItemDiscount';
-export * from './InvoicePayment';
-export * from './InvoicePatientPayment';
-export * from './InvoiceInsurerPayment';
 
 export * from './ReferenceDrug';
+export * from './ReferenceDrugFacility';
 export * from './MedicationAdministrationRecord';
 export * from './MedicationAdministrationRecordDose';
 export * from './ReferenceMedicationTemplate';
 
 export * from './PharmacyOrder';
 export * from './PharmacyOrderPrescription';
+export * from './MedicationDispense';
 
 export * from './Notification';
 
@@ -155,4 +152,8 @@ export * from './SyncLookupTick';
 
 export * from './AccessLog';
 export * from './ChangeLog';
+export * from './UserLeave';
+
+export * from './LocationAssignmentTemplate';
+export * from './LocationAssignment';
 export * from './DHIS2PushLog';
